@@ -241,10 +241,10 @@ class ISAModelClient:
         """Make HTTP request to remote API endpoint"""
         if not self.service_endpoint:
             raise ValueError("Service endpoint not configured for remote API calls")
-        
+
         session = await self._get_http_session()
         url = f"{self.service_endpoint.rstrip('/')}/{endpoint.lstrip('/')}"
-        
+
         try:
             async with session.post(url, json=data) as response:
                 if response.status == 401:
@@ -254,12 +254,80 @@ class ISAModelClient:
                 elif not response.ok:
                     error_detail = await response.text()
                     raise Exception(f"API request failed ({response.status}): {error_detail}")
-                
+
                 return await response.json()
-                
+
         except Exception as e:
             logger.error(f"Remote API request failed: {e}")
             raise
+
+    async def _make_streaming_api_request(self, endpoint: str, data: Dict[str, Any]) -> Dict[str, Any]:
+        """Make streaming HTTP request to remote API endpoint (Server-Sent Events)"""
+        if not self.service_endpoint:
+            raise ValueError("Service endpoint not configured for remote API calls")
+
+        session = await self._get_http_session()
+        url = f"{self.service_endpoint.rstrip('/')}/{endpoint.lstrip('/')}"
+
+        async def stream_generator():
+            """Generator that yields tokens from SSE stream"""
+            try:
+                async with session.post(url, json=data) as response:
+                    if response.status == 401:
+                        raise Exception("Authentication required or invalid API key")
+                    elif response.status == 403:
+                        raise Exception("Insufficient permissions")
+                    elif not response.ok:
+                        error_detail = await response.text()
+                        raise Exception(f"API request failed ({response.status}): {error_detail}")
+
+                    # Read SSE stream line by line
+                    async for line in response.content:
+                        line = line.decode('utf-8').strip()
+
+                        # Skip empty lines
+                        if not line:
+                            continue
+
+                        # Parse SSE format: "data: {...}"
+                        if line.startswith("data: "):
+                            data_str = line[6:]  # Remove "data: " prefix
+
+                            # Skip [DONE] marker
+                            if data_str == "[DONE]":
+                                break
+
+                            try:
+                                import json
+                                event_data = json.loads(data_str)
+
+                                # Yield token if present
+                                if 'token' in event_data:
+                                    yield event_data['token']
+                                # Yield metadata if present (final event)
+                                elif 'metadata' in event_data:
+                                    yield event_data  # Pass metadata dict
+                                # Handle error events
+                                elif 'error' in event_data:
+                                    logger.error(f"Stream error: {event_data}")
+                                    break
+                            except json.JSONDecodeError:
+                                logger.warning(f"Failed to parse SSE data: {data_str}")
+                                continue
+
+            except Exception as e:
+                logger.error(f"Streaming API request failed: {e}")
+                raise
+
+        # Return response with stream generator
+        return {
+            "success": True,
+            "stream": stream_generator(),
+            "metadata": {
+                "streaming": True,
+                "endpoint": "remote"
+            }
+        }
     
     async def close(self):
         """Close HTTP session and cleanup resources"""
@@ -277,7 +345,7 @@ class ISAModelClient:
         stream: Optional[bool] = None,
         **kwargs
     ) -> Dict[str, Any]:
-        """Invoke remote API endpoint"""
+        """Invoke remote API endpoint with streaming support"""
         try:
             # Prepare request data for unified API
             request_data = {
@@ -285,15 +353,19 @@ class ISAModelClient:
                 "service_type": service_type,
                 **kwargs
             }
-            
+
             # Add model and provider if specified
             if model:
                 request_data["model"] = model
             if provider:
                 request_data["provider"] = provider
-            # For remote API, disable streaming to get JSON response
-            request_data["stream"] = False
-            
+
+            # Set streaming based on parameter (default True for text/chat)
+            should_stream = stream
+            if should_stream is None and service_type == "text" and task == "chat":
+                should_stream = True
+            request_data["stream"] = should_stream if should_stream is not None else False
+
             # Handle different input data types
             if isinstance(input_data, (str, Path)):
                 request_data["input_data"] = str(input_data)
@@ -307,12 +379,15 @@ class ISAModelClient:
                     request_data["data_type"] = "base64"
                 else:
                     request_data["input_data"] = str(input_data)
-            
-            # Make API request
-            response = await self._make_api_request("api/v1/invoke", request_data)
-            
-            return response
-            
+
+            # Check if we should handle streaming response
+            if request_data.get("stream"):
+                return await self._make_streaming_api_request("api/v1/invoke", request_data)
+            else:
+                # Make regular JSON API request
+                response = await self._make_api_request("api/v1/invoke", request_data)
+                return response
+
         except Exception as e:
             logger.error(f"Remote API invocation failed: {e}")
             return {
@@ -410,6 +485,9 @@ class ISAModelClient:
                 else:
                     stream = False  # Disable for other text tasks
             
+            # Extract user_id from kwargs if present
+            user_id = kwargs.pop('user_id', None)
+
             # If streaming is enabled for text tasks, return streaming response
             if stream and service_type == "text":
                 return await self._invoke_service_streaming(
@@ -422,6 +500,7 @@ class ISAModelClient:
                     output_format=output_format,
                     json_schema=json_schema,
                     repair_attempts=repair_attempts,
+                    user_id=user_id,
                     **kwargs
                 )
             else:
@@ -436,6 +515,7 @@ class ISAModelClient:
                     output_format=output_format,
                     json_schema=json_schema,
                     repair_attempts=repair_attempts,
+                    user_id=user_id,
                     **kwargs
                 )
                 
@@ -922,13 +1002,18 @@ class ISAModelClient:
         input_data: Any,
         task: str,
         service_type: str,
+        user_id: Optional[str] = None,
         **kwargs
     ) -> Any:
         """Execute the task using the appropriate service"""
-        
+
         try:
             self._validate_service_type(service_type)
             unified_task = self._map_task(task, service_type)
+
+            # Store user_id in kwargs so services can access it for billing
+            if user_id:
+                kwargs['user_id'] = user_id
             
             if service_type == "vision":
                 return await service.invoke(
@@ -1122,6 +1207,7 @@ class ISAModelClient:
         output_format: Optional[str] = None,
         json_schema: Optional[Dict] = None,
         repair_attempts: Optional[int] = 3,
+        user_id: Optional[str] = None,
         **kwargs
     ) -> Dict[str, Any]:
         """Service invoke that returns streaming response with async generator"""
@@ -1217,6 +1303,7 @@ class ISAModelClient:
         output_format: Optional[str] = None,
         json_schema: Optional[Dict] = None,
         repair_attempts: Optional[int] = 3,
+        user_id: Optional[str] = None,
         **kwargs
     ) -> Dict[str, Any]:
         """Direct service invoke - passes LangChain objects and tools directly to services"""
@@ -1297,6 +1384,7 @@ class ISAModelClient:
                     input_data=input_data,
                     task=task,
                     service_type=service_type,
+                    user_id=user_id,
                     **task_kwargs
                 )
             except Exception as e:
@@ -1335,6 +1423,7 @@ class ISAModelClient:
                             input_data=input_data,
                             task=task,
                             service_type=service_type,
+                            user_id=user_id,
                             **task_kwargs
                         )
                     else:
