@@ -1,4 +1,4 @@
-z"""
+"""
 Centralized Configuration Management for ISA Model SDK
 
 This module provides unified configuration management across all modules:
@@ -54,7 +54,7 @@ class LocalGPUGlobalConfig:
     enable_local_gpu: bool = True
     auto_detect_gpu: bool = True
     workspace_dir: str = "./local_deployments"
-    preferred_backend: str = "transformers"  # vllm, tensorrt_llm, transformers
+    preferred_backend: str = "api"  # cloud api only
     
     # Default resource settings
     default_gpu_memory_fraction: float = 0.9
@@ -114,7 +114,7 @@ class GlobalConfig:
     local_gpu_memory_fraction: float = 0.9
     local_workspace_dir: str = "./local_deployments"
     auto_detect_gpu: bool = True
-    preferred_local_backend: str = "transformers"  # vllm, tensorrt_llm, transformers
+    preferred_local_backend: str = "api"  # cloud api only
     
     # Local service defaults
     local_health_check_interval: int = 30  # seconds
@@ -263,7 +263,7 @@ class ConfigManager:
             "enable_local_gpu": os.getenv("ISA_ENABLE_LOCAL_GPU", "true").lower() == "true",
             "auto_detect_gpu": os.getenv("ISA_AUTO_DETECT_GPU", "true").lower() == "true",
             "workspace_dir": os.getenv("ISA_LOCAL_WORKSPACE_DIR", "./local_deployments"),
-            "preferred_backend": os.getenv("ISA_PREFERRED_LOCAL_BACKEND", "transformers"),
+            "preferred_backend": os.getenv("ISA_PREFERRED_LOCAL_BACKEND", "api"),
             "default_gpu_memory_fraction": float(os.getenv("ISA_GPU_MEMORY_FRACTION", "0.9")),
             "health_check_interval": int(os.getenv("ISA_LOCAL_HEALTH_CHECK_INTERVAL", "30")),
             "max_concurrent_services": int(os.getenv("ISA_MAX_CONCURRENT_SERVICES", "3")),
