@@ -3,21 +3,26 @@ Logging module for ISA Model
 
 Provides comprehensive logging capabilities including:
 - Loki-based centralized application logging (via loki_logger)
-- InfluxDB-based inference metrics logging (via influx_logger)
-- Real-time monitoring and alerting
+- Basic inference logging with request tracking
 
 Architecture:
 - Loki: General application logs (INFO, WARNING, ERROR, DEBUG)
-- InfluxDB: Inference metrics (tokens, costs, performance data)
+- Basic logging: Simple request tracking and basic metrics
 """
 
-# InfluxDB inference metrics logging
-from .influx_logger import (
-    InfluxInferenceLogger,
-    InferenceLogEntry,
-    get_inference_logger,
-    generate_request_id
-)
+# Basic inference logging (no external dependencies)
+import uuid
+import logging
+from .inference_logger import InferenceLogger
+
+def generate_request_id():
+    """Generate unique request ID for tracking"""
+    return str(uuid.uuid4())
+
+def get_inference_logger():
+    """Get enhanced inference logger with compatibility methods"""
+    base_logger = logging.getLogger("isa_model.inference")
+    return InferenceLogger(base_logger)
 
 # Loki centralized application logging
 from .loki_logger import (
@@ -34,9 +39,7 @@ from .loki_logger import (
 )
 
 __all__ = [
-    # InfluxDB inference logging
-    'InfluxInferenceLogger',
-    'InferenceLogEntry',
+    # Basic inference logging
     'get_inference_logger',
     'generate_request_id',
 
