@@ -2,8 +2,6 @@ from typing import Dict, Optional, List, Any
 import logging
 from pathlib import Path
 from datetime import datetime
-from huggingface_hub import hf_hub_download, snapshot_download
-from huggingface_hub.errors import HfHubHTTPError
 from .model_storage import ModelStorage, LocalModelStorage
 from .model_repo import ModelRegistry, ModelType, ModelCapability
 from .model_billing_tracker import ModelBillingTracker, ModelOperationType
@@ -102,73 +100,7 @@ class ModelManager:
             logger.warning(f"Failed to find cheapest model for {provider}: {e}")
             return None
 
-    async def get_model(self, 
-                       model_id: str, 
-                       repo_id: str,
-                       model_type: ModelType,
-                       capabilities: List[ModelCapability],
-                       revision: Optional[str] = None,
-                       force_download: bool = False) -> Optional[Path]:
-        """
-        Get model files, downloading if necessary
-        
-        Args:
-            model_id: Unique identifier for the model
-            repo_id: Hugging Face repository ID
-            model_type: Type of model (LLM, embedding, etc.)
-            capabilities: List of model capabilities
-            revision: Specific model version/tag
-            force_download: Force re-download even if cached
-            
-        Returns:
-            Path to the model files or None if failed
-        """
-        # Check if model is already downloaded
-        if not force_download:
-            model_path = await self.storage.load_model(model_id)
-            if model_path:
-                logger.info(f"Using cached model {model_id}")
-                return model_path
-        
-        try:
-            # Download model files
-            logger.info(f"Downloading model {model_id} from {repo_id}")
-            model_dir = Path(f"./models/temp/{model_id}")
-            model_dir.mkdir(parents=True, exist_ok=True)
-
-            snapshot_download(
-                repo_id=repo_id,
-                revision=revision,
-                local_dir=model_dir,
-                local_dir_use_symlinks=False
-            )
-
-            # Save model and metadata
-            metadata = {
-                "repo_id": repo_id,
-                "revision": revision,
-                "downloaded_at": str(Path(model_dir).stat().st_mtime)
-            }
-
-            # Register model
-            self.registry.register_model(
-                model_id=model_id,
-                model_type=model_type,
-                capabilities=capabilities,
-                metadata=metadata
-            )
-
-            # Save model files
-            await self.storage.save_model(model_id, str(model_dir), metadata)
-
-            return await self.storage.load_model(model_id)
-
-        except HfHubHTTPError as e:
-            logger.error(f"Failed to download model {model_id}: {e}")
-            return None
-        except Exception as e:
-            logger.error(f"Unexpected error downloading model {model_id}: {e}")
-            return None
+    # Local model download functionality removed - use cloud API services only
     
     async def list_models(self) -> List[Dict[str, Any]]:
         """List all downloaded models with their metadata"""
