@@ -181,6 +181,9 @@ class AIFactory:
         elif provider == "isa":
             final_model_name = model_name or "isa-omniparser-ui-detection"
             final_provider = provider
+        elif provider == "yyds":
+            final_model_name = model_name or "gpt-4o-mini"
+            final_provider = provider
         else:
             # Default provider selection
             final_provider = provider or "openai"
@@ -190,6 +193,8 @@ class AIFactory:
                 final_model_name = model_name or "llama3.2-vision:latest"
             elif final_provider == "isa":
                 final_model_name = model_name or "isa-omniparser-ui-detection"
+            elif final_provider == "yyds":
+                final_model_name = model_name or "gpt-4o-mini"
             else:
                 final_model_name = model_name or "gpt-4.1-mini"
         
@@ -207,6 +212,11 @@ class AIFactory:
                 from isa_model.inference.services.vision.isa_vision_service import ISAVisionService
                 logger.info(f"Creating ISA Vision Service with model: {final_model_name}")
                 return ISAVisionService()
+            elif final_provider == "yyds":
+                from isa_model.inference.services.vision.yyds_vision_service import YydsVisionService
+                logger.info(f"Creating YYDS Vision Service with model: {final_model_name}")
+                return YydsVisionService(provider_name=final_provider, model_name=final_model_name,
+                                        model_manager=self.model_manager, config_manager=self.config_manager)
             else:
                 raise ValueError(f"Unsupported vision provider: {final_provider}")
         except Exception as e:
@@ -258,6 +268,10 @@ class AIFactory:
                 from isa_model.inference.services.img.replicate_image_gen_service import ReplicateImageGenService
                 return ReplicateImageGenService(provider_name=final_provider, model_name=final_model_name,
                                               model_manager=self.model_manager, config_manager=self.config_manager)
+            elif final_provider == "openai":
+                from isa_model.inference.services.img.services.openai_dalle_service import OpenAIDALLEService
+                return OpenAIDALLEService(provider_name=final_provider, model_name=final_model_name,
+                                        model_manager=self.model_manager, config_manager=self.config_manager)
             else:
                 raise ValueError(f"Unsupported image generation provider: {final_provider}")
         except Exception as e:
