@@ -60,7 +60,7 @@ class OpenAIRealtimeService(BaseRealtimeService):
         self._setup_default_handlers()
     
     async def create_session(
-        self, 
+        self,
         instructions: str = "You are a helpful assistant.",
         modalities: Optional[List[str]] = None,
         voice: str = "alloy",
@@ -68,6 +68,9 @@ class OpenAIRealtimeService(BaseRealtimeService):
     ) -> Dict[str, Any]:
         """Create a new realtime session"""
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.pop('user_id', None)
+
             # Prepare session configuration
             session_config = self.default_config.copy()
             session_config.update({
@@ -76,24 +79,26 @@ class OpenAIRealtimeService(BaseRealtimeService):
                 "voice": voice,
                 **kwargs
             })
-            
+
             # Store session config for WebSocket connection
             self.session_config = session_config
-            
+
             # Generate a session ID (WebSocket-based, no REST endpoint)
             import uuid
             self.session_id = str(uuid.uuid4())
-            
+
             # Track session creation for billing
-            await self._track_usage(
-                service_type=ServiceType.AUDIO_REALTIME,
-                operation="create_session",
-                metadata={
-                    "session_id": self.session_id,
-                    "model": self.model_name,
-                    "modalities": session_config["modalities"]
-                }
-            )
+            if self._current_user_id:
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
+                    service_type=ServiceType.AUDIO_REALTIME,
+                    operation="create_session",
+                    metadata={
+                        "session_id": self.session_id,
+                        "model": self.model_name,
+                        "modalities": session_config["modalities"]
+                    }
+                )
             
             return {
                 "id": self.session_id,
@@ -259,19 +264,21 @@ class OpenAIRealtimeService(BaseRealtimeService):
                             # Response completed
                             response = event.get("response", {})
                             usage = response.get("usage", {})
-                            
+
                             # Track usage for billing
-                            await self._track_usage(
-                                service_type=ServiceType.AUDIO_REALTIME,
-                                operation="realtime_response",
-                                input_tokens=usage.get("input_tokens", 0),
-                                output_tokens=usage.get("output_tokens", 0),
-                                metadata={
-                                    "response_id": response.get("id"),
-                                    "model": self.model_name,
-                                    "status": response.get("status")
-                                }
-                            )
+                            if self._current_user_id:
+                                await self._publish_billing_event(
+                                    user_id=self._current_user_id,
+                                    service_type=ServiceType.AUDIO_REALTIME,
+                                    operation="realtime_response",
+                                    input_tokens=usage.get("input_tokens", 0),
+                                    output_tokens=usage.get("output_tokens", 0),
+                                    metadata={
+                                        "response_id": response.get("id"),
+                                        "model": self.model_name,
+                                        "status": response.get("status")
+                                    }
+                                )
                             
                             yield {
                                 "type": "response_done",
