@@ -50,16 +50,18 @@ class OpenAISTTService(BaseSTTService):
     async def transcribe(self, audio_file: Union[str, BinaryIO, bytes], language: Optional[str] = None, prompt: Optional[str] = None, **kwargs) -> Dict[str, Any]:
         """
         Transcribe audio file to text using OpenAI's Whisper model.
-        
+
         Args:
             audio_file: Path to audio file or file-like object
             language: Optional language code for better accuracy
             **kwargs: Additional parameters for the transcription API
-            
+
         Returns:
             Dict containing transcription result and metadata
         """
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
             # Prepare request parameters
             transcription_params = {
                 "model": self.model_name,
@@ -91,8 +93,29 @@ class OpenAISTTService(BaseSTTService):
                     **transcription_params
                 )
             elif isinstance(audio_file, str):
-                # Check if it's a base64 string or file path
-                if len(audio_file) > 100 and not os.path.exists(audio_file):
+                # Check if it's a URL, base64 string, or file path
+                if audio_file.startswith(('http://', 'https://')):
+                    # Fetch audio from URL
+                    logger.info(f"Fetching audio from URL: {audio_file}")
+                    async with aiohttp.ClientSession() as session:
+                        async with session.get(audio_file) as response:
+                            if response.status == 200:
+                                audio_data = await response.read()
+                                from io import BytesIO
+                                audio_buffer = BytesIO(audio_data)
+                                # Extract filename from URL or use default
+                                filename = audio_file.split('/')[-1] if '/' in audio_file else 'audio.wav'
+                                if not filename.endswith(('.mp3', '.wav', '.m4a', '.flac', '.ogg', '.webm', '.mp4')):
+                                    filename += '.wav'
+                                audio_buffer.name = filename
+                                logger.info(f"Downloaded {len(audio_data)} bytes from URL")
+                                transcription = await self.client.audio.transcriptions.create(
+                                    file=audio_buffer,
+                                    **transcription_params
+                                )
+                            else:
+                                raise ValueError(f"Failed to fetch audio from URL: HTTP {response.status}")
+                elif len(audio_file) > 100 and not os.path.exists(audio_file):
                     # Likely a base64 string
                     try:
                         import base64
@@ -140,17 +163,19 @@ class OpenAISTTService(BaseSTTService):
             }
             
             # Track usage for billing
-            await self._track_usage(
-                service_type="audio_stt",
-                operation="transcribe",
-                input_units=result["usage"]["input_units"],
-                output_tokens=result["usage"]["output_tokens"],
-                metadata={
-                    "language": result.get("language"),
-                    "model_name": self.model_name,
-                    "provider": self.provider_name
-                }
-            )
+            if self._current_user_id:
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
+                    service_type="audio_stt",
+                    operation="transcribe",
+                    input_units=result["usage"]["input_units"],
+                    output_tokens=result["usage"]["output_tokens"],
+                    metadata={
+                        "language": result.get("language"),
+                        "model_name": self.model_name,
+                        "provider": self.provider_name
+                    }
+                )
             
             return result
             
@@ -158,23 +183,44 @@ class OpenAISTTService(BaseSTTService):
             logger.error(f"Transcription failed: {e}")
             raise
 
+    async def invoke(
+        self,
+        audio_input: Optional[Union[str, BinaryIO, bytes]] = None,
+        task: Optional[str] = None,
+        **kwargs
+    ) -> Dict[str, Any]:
+        """
+        Unified invoke method for STT service.
+        Follows OpenAI pattern: audio → text
+        """
+        if audio_input is None:
+            raise ValueError("Audio input is required for STT (speech-to-text)")
+
+        # STT always does transcription (or translation if specified)
+        if task == "translate":
+            return await self.translate(audio_file=audio_input, **kwargs)
+        else:
+            return await self.transcribe(audio_file=audio_input, **kwargs)
+
     @retry(
         stop=stop_after_attempt(3),
         wait=wait_exponential(multiplier=1, min=4, max=10),
         reraise=True
     )
-    async def translate(self, audio_file: Union[str, BinaryIO, bytes]) -> Dict[str, Any]:
+    async def translate(self, audio_file: Union[str, BinaryIO, bytes], **kwargs) -> Dict[str, Any]:
         """
         Translate audio file to English text using OpenAI's Whisper model.
-        
+
         Args:
             audio_file: Path to audio file or file-like object
             **kwargs: Additional parameters for the translation API
-            
+
         Returns:
             Dict containing translation result and metadata
         """
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
             # Prepare request parameters
             translation_params = {
                 "model": self.model_name,
@@ -209,17 +255,19 @@ class OpenAISTTService(BaseSTTService):
             }
             
             # Track usage for billing
-            await self._track_usage(
-                service_type="audio_stt",
-                operation="translate",
-                input_units=result["usage"]["input_units"],
-                output_tokens=result["usage"]["output_tokens"],
-                metadata={
-                    "target_language": "en",
-                    "model_name": self.model_name,
-                    "provider": self.provider_name
-                }
-            )
+            if self._current_user_id:
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
+                    service_type="audio_stt",
+                    operation="translate",
+                    input_units=result["usage"]["input_units"],
+                    output_tokens=result["usage"]["output_tokens"],
+                    metadata={
+                        "target_language": "en",
+                        "model_name": self.model_name,
+                        "provider": self.provider_name
+                    }
+                )
             
             return result
             
