@@ -45,9 +45,11 @@ class OllamaEmbedService(BaseEmbedService):
             logger.error(f"Failed to initialize Ollama client: {e}")
             raise ValueError(f"Failed to initialize Ollama client: {e}") from e
     
-    async def create_text_embedding(self, text: str) -> List[float]:
+    async def create_text_embedding(self, text: str, **kwargs) -> List[float]:
         """Create embedding for single text"""
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
             payload = {
                 "model": self.model_name,
                 "prompt": text
@@ -60,18 +62,20 @@ class OllamaEmbedService(BaseEmbedService):
             embedding = result["embedding"]
             
             # Track usage for billing (estimate token usage for Ollama)
-            estimated_tokens = len(text.split()) * 1.3  # Rough estimation
-            await self._track_usage(
-                service_type="embedding",
-                operation="create_text_embedding",
-                input_tokens=int(estimated_tokens),
-                output_tokens=0,
-                metadata={
-                    "model": self.model_name,
-                    "text_length": len(text),
-                    "estimated_tokens": int(estimated_tokens)
-                }
-            )
+            if self._current_user_id:
+                estimated_tokens = len(text.split()) * 1.3  # Rough estimation
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
+                    service_type="embedding",
+                    operation="create_text_embedding",
+                    input_tokens=int(estimated_tokens),
+                    output_tokens=0,
+                    metadata={
+                        "model": self.model_name,
+                        "text_length": len(text),
+                        "estimated_tokens": int(estimated_tokens)
+                    }
+                )
             
             return embedding
             
@@ -82,31 +86,52 @@ class OllamaEmbedService(BaseEmbedService):
             logger.error(f"Error creating text embedding: {e}")
             raise
     
-    async def create_text_embeddings(self, texts: List[str]) -> List[List[float]]:
+    async def create_text_embeddings(self, texts: List[str], **kwargs) -> List[List[float]]:
         """Create embeddings for multiple texts concurrently"""
         if not texts:
             return []
-        
-        tasks = [self.create_text_embedding(text) for text in texts]
+
+        # Extract user_id from kwargs for billing
+        self._current_user_id = kwargs.get('user_id')
+
+        tasks = [self.create_text_embedding(text, **kwargs) for text in texts]
         embeddings = await asyncio.gather(*tasks)
-        
+
         # Track batch usage for billing
-        total_estimated_tokens = sum(len(text.split()) * 1.3 for text in texts)
-        await self._track_usage(
-            service_type="embedding",
-            operation="create_text_embeddings",
-            input_tokens=int(total_estimated_tokens),
-            output_tokens=0,
-            metadata={
-                "model": self.model_name,
-                "batch_size": len(texts),
-                "total_text_length": sum(len(t) for t in texts),
-                "estimated_tokens": int(total_estimated_tokens)
-            }
-        )
+        if self._current_user_id:
+            total_estimated_tokens = sum(len(text.split()) * 1.3 for text in texts)
+            await self._publish_billing_event(
+                user_id=self._current_user_id,
+                service_type="embedding",
+                operation="create_text_embeddings",
+                input_tokens=int(total_estimated_tokens),
+                output_tokens=0,
+                metadata={
+                    "model": self.model_name,
+                    "batch_size": len(texts),
+                    "total_text_length": sum(len(t) for t in texts),
+                    "estimated_tokens": int(total_estimated_tokens)
+                }
+            )
         
         return embeddings
-    
+
+    async def invoke(
+        self,
+        input_data: Optional[str] = None,
+        task: Optional[str] = None,
+        **kwargs
+    ) -> List[float]:
+        """
+        Unified invoke method for embedding service.
+        Follows pattern: text → vector embedding
+        """
+        if input_data is None:
+            raise ValueError("Text input is required for embedding generation")
+
+        # Embedding service generates vector from text
+        return await self.create_text_embedding(text=input_data, **kwargs)
+
     async def create_chunks(self, text: str, metadata: Optional[Dict] = None) -> List[Dict]:
         """Create text chunks with embeddings"""
         chunk_size = 200  # words
