@@ -617,6 +617,7 @@ class BaseLLMService(BaseService):
     
     async def _track_llm_usage(
         self,
+        user_id: str,  # REQUIRED: User ID from gateway authentication
         operation: str,
         input_tokens: Optional[int] = None,
         output_tokens: Optional[int] = None,
@@ -624,20 +625,28 @@ class BaseLLMService(BaseService):
     ) -> float:
         """
         Track LLM usage using the unified BaseService billing system
-        
+
+        Args:
+            operation: Operation type (e.g., "chat", "generate")
+            input_tokens: Number of input tokens
+            output_tokens: Number of output tokens
+            metadata: Additional metadata
+            user_id: User ID for billing (from gateway auth)
+
         Returns:
             Cost in USD
         """
         from isa_model.core.types import ServiceType
-        
-        await self._track_usage(
+
+        await self._publish_billing_event(
+            user_id=user_id,
             service_type=ServiceType.LLM,
             operation=operation,
             input_tokens=input_tokens,
             output_tokens=output_tokens,
             metadata=metadata
         )
-        
+
         # Return calculated cost
         if input_tokens is not None and output_tokens is not None:
             return self.model_manager.calculate_cost(
