@@ -373,6 +373,9 @@ Only respond normally WITHOUT JSON if the request does NOT require any of the av
             **kwargs: Additional parameters
         """
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
+
             # Use adapter manager to prepare messages
             messages = self._prepare_messages(input_data)
 
@@ -485,17 +488,19 @@ Only respond normally WITHOUT JSON if the request does NOT require any of the av
         """Track billing information"""
         provider_config = self.get_provider_config()
 
-        await self._track_usage(
-            service_type=ServiceType.LLM,
-            operation="chat",
-            input_tokens=usage.prompt_tokens,
-            output_tokens=usage.completion_tokens,
-            metadata={
-                "temperature": provider_config.get("temperature", 0.7),
-                "max_tokens": provider_config.get("max_tokens", 1024),
-                "inference_speed": "ultra-fast"
-            }
-        )
+        if self._current_user_id:
+            await self._publish_billing_event(
+                user_id=self._current_user_id,
+                service_type=ServiceType.LLM,
+                operation="chat",
+                input_tokens=usage.prompt_tokens,
+                output_tokens=usage.completion_tokens,
+                metadata={
+                    "temperature": provider_config.get("temperature", 0.7),
+                    "max_tokens": provider_config.get("max_tokens", 1024),
+                    "inference_speed": "ultra-fast"
+                }
+            )
 
     def get_token_usage(self) -> Dict[str, Any]:
         """Get total token usage statistics"""
