@@ -426,75 +426,67 @@ class StandardMessageAdapter:
             return [{"role": "user", "content": str(input_data)}]
     
     def from_openai_format(self, response: Union[str, Any], original_input: Any) -> Any:
-        """从 OpenAI 格式转换回原始格式"""
-        # For consistency, always return a message object similar to LangChain
-        try:
-            from langchain_core.messages import AIMessage
-            
-            # Extract content - handle None content for tool calls
-            if isinstance(response, str):
-                content = response
-            elif hasattr(response, 'content'):
-                content = response.content if response.content is not None else ""
-            else:
-                content = str(response)
-            
-            # Handle tool_calls if present
-            if hasattr(response, 'tool_calls') and response.tool_calls:
-                # Convert to LangChain format tool_calls
-                tool_calls = []
-                for tc in response.tool_calls:
-                    if hasattr(tc, 'function'):
-                        # OpenAI format: tc.function.name, tc.function.arguments
-                        try:
-                            import json
-                            args = json.loads(tc.function.arguments) if tc.function.arguments else {}
-                        except:
-                            args = {}
-                        
-                        tool_call = {
-                            "name": tc.function.name,
-                            "args": args,
-                            "id": getattr(tc, 'id', 'unknown'),
-                            "type": "tool_call"
-                        }
-                        tool_calls.append(tool_call)
-                
-                return AIMessage(content=content, tool_calls=tool_calls)
-            else:
-                return AIMessage(content=content)
-                
-        except ImportError:
-            # Fallback: create a simple message object
-            class SimpleAIMessage:
-                def __init__(self, content, tool_calls=None):
-                    self.content = content
-                    self.type = "ai"
-                    self.tool_calls = tool_calls or []
-            
+        """从 OpenAI 格式转换回原始格式
+
+        Return format matches the input format:
+        - String input → Plain string output
+        - List of dicts (OpenAI chat format) → OpenAI completion dict
+        """
+        # Extract content from response
+        if isinstance(response, str):
+            content = response
+        elif hasattr(response, 'content'):
+            content = response.content if response.content is not None else ""
+        else:
+            content = str(response)
+
+        # Determine output format based on original input
+        if isinstance(original_input, str):
+            # String input → return plain string
+            return content
+
+        elif isinstance(original_input, list) and original_input and isinstance(original_input[0], dict):
+            # OpenAI chat format input → return OpenAI completion format
+            completion = {
+                "id": f"chatcmpl-{hash(content) % 1000000}",
+                "object": "chat.completion",
+                "created": int(__import__('time').time()),
+                "model": "unknown",
+                "choices": [
+                    {
+                        "index": 0,
+                        "message": {
+                            "role": "assistant",
+                            "content": content
+                        },
+                        "finish_reason": "stop"
+                    }
+                ]
+            }
+
             # Handle tool_calls if present
             if hasattr(response, 'tool_calls') and response.tool_calls:
                 tool_calls = []
                 for tc in response.tool_calls:
                     if hasattr(tc, 'function'):
-                        try:
-                            import json
-                            args = json.loads(tc.function.arguments) if tc.function.arguments else {}
-                        except:
-                            args = {}
-                        
                         tool_call = {
-                            "name": tc.function.name,
-                            "args": args,
-                            "id": getattr(tc, 'id', 'unknown'),
-                            "type": "tool_call"
+                            "id": getattr(tc, 'id', f"call_{len(tool_calls)}"),
+                            "type": "function",
+                            "function": {
+                                "name": tc.function.name,
+                                "arguments": tc.function.arguments
+                            }
                         }
                         tool_calls.append(tool_call)
-                
-                return SimpleAIMessage(content, tool_calls)
-            else:
-                content = response if isinstance(response, str) else getattr(response, 'content', str(response))
-                return SimpleAIMessage(content)
+
+                completion["choices"][0]["message"]["tool_calls"] = tool_calls
+                completion["choices"][0]["finish_reason"] = "tool_calls"
+
+            return completion
+
+        else:
+            # For other inputs (list of strings, etc.), return plain string
+            return content
 
 
 # ============= 适配器管理器 =============
