@@ -507,8 +507,8 @@ class ResponseParser:
 class LLMMetrics:
     """
     LLM性能指标计算工具
-    
-    注意：计费和使用跟踪功能已经统一到BaseService中的_track_usage()方法。
+
+    注意：计费和使用跟踪功能已经统一到BaseService中的_publish_billing_event()方法。
     LLM服务应该使用BaseLLMService中的_track_llm_usage()方法来跟踪使用情况。
     """
     
