@@ -59,19 +59,21 @@ class OllamaLLMService(BaseLLMService):
         
         return bound_service
     
-    async def ainvoke(self, input_data: Union[str, List[Dict[str, str]], Any]) -> Union[str, Any]:
+    async def ainvoke(self, input_data: Union[str, List[Dict[str, str]], Any], **kwargs) -> Union[str, Any]:
         """
         Universal async invocation method that handles different input types
-        
+
         Args:
             input_data: Can be:
                 - str: Simple text prompt
                 - list: Message history like [{"role": "user", "content": "hello"}]
                 - Any: LangChain message objects or other formats
-            
+
         Returns:
             Model response (string for simple cases, object for complex cases)
         """
+        # Extract user_id from kwargs
+        user_id = kwargs.pop('user_id', None)
         try:
             # Ensure client is available
             self._ensure_client()
@@ -115,7 +117,7 @@ class OllamaLLMService(BaseLLMService):
             # Update token usage if available
             if "eval_count" in result:
                 self._update_token_usage(result)
-                await self._track_ollama_billing(result)
+                await self._track_ollama_billing(result, user_id=user_id)
             
             # Handle tool calls if present - let adapter process the complete message
             message = result["message"]
@@ -252,20 +254,21 @@ class OllamaLLMService(BaseLLMService):
         # Get final response from the model
         return await self.ainvoke(messages)
     
-    async def _track_streaming_usage(self, messages: List[Dict[str, str]], content: str):
+    async def _track_streaming_usage(self, messages: List[Dict[str, str]], content: str, user_id: Optional[str] = None):
         """Track usage for streaming requests (estimated)"""
         # Create a mock usage object for tracking
         class MockUsage:
             def __init__(self):
                 self.prompt_tokens = len(str(messages)) // 4  # Rough estimate
-                self.completion_tokens = len(content) // 4   # Rough estimate  
+                self.completion_tokens = len(content) // 4   # Rough estimate
                 self.total_tokens = self.prompt_tokens + self.completion_tokens
-        
+
         usage = MockUsage()
         self._update_token_usage_from_mock(usage)
-        
+
         # Track billing
         await self._track_llm_usage(
+            user_id=user_id or "anonymous",
             operation="chat_stream",
             input_tokens=usage.prompt_tokens,
             output_tokens=usage.completion_tokens,
@@ -304,12 +307,13 @@ class OllamaLLMService(BaseLLMService):
         self.total_token_usage["total_tokens"] += self.last_token_usage["total_tokens"]
         self.total_token_usage["requests_count"] += 1
     
-    async def _track_ollama_billing(self, result: Dict[str, Any]):
+    async def _track_ollama_billing(self, result: Dict[str, Any], user_id: Optional[str] = None):
         """Track billing information for Ollama requests"""
         prompt_tokens = result.get("prompt_eval_count", 0)
         completion_tokens = result.get("eval_count", 0)
-        
+
         await self._track_llm_usage(
+            user_id=user_id or "anonymous",
             operation="chat",
             input_tokens=prompt_tokens,
             output_tokens=completion_tokens,
@@ -348,19 +352,21 @@ class OllamaLLMService(BaseLLMService):
             except Exception as e:
                 logger.warning(f"Error closing Ollama client: {e}")
 
-    async def astream(self, input_data: Union[str, List[Dict[str, str]], Any]) -> AsyncGenerator[str, None]:
+    async def astream(self, input_data: Union[str, List[Dict[str, str]], Any], **kwargs) -> AsyncGenerator[str, None]:
         """
         True streaming method that yields tokens one by one as they arrive
-        
+
         Args:
             input_data: Can be:
                 - str: Simple text prompt
                 - list: Message history like [{"role": "user", "content": "hello"}]
                 - Any: LangChain message objects or other formats
-            
+
         Yields:
             Individual tokens as they arrive from the model
         """
+        # Extract user_id from kwargs
+        user_id = kwargs.pop('user_id', None)
         try:
             # Ensure client is available
             self._ensure_client()
@@ -405,7 +411,7 @@ class OllamaLLMService(BaseLLMService):
                 
                 # Track usage after streaming is complete (estimated)
                 full_content = "".join(content_chunks)
-                await self._track_streaming_usage(messages, full_content)
+                await self._track_streaming_usage(messages, full_content, user_id=user_id)
                 
             except Exception as e:
                 logger.error(f"Error in streaming: {e}")
