@@ -374,13 +374,16 @@ class OpenAILLMService(BaseLLMService):
     async def ainvoke(self, input_data: Union[str, List[Dict[str, str]], Any], show_reasoning: bool = False, **extra_kwargs) -> Union[str, Any]:
         """
         Unified invoke method for all input types
-        
+
         Args:
             input_data: Input messages or text
             show_reasoning: If True and model supports it, show reasoning process using Responses API
             **extra_kwargs: Additional parameters to pass to the API (e.g., response_format)
         """
         try:
+            # Extract user_id from kwargs for billing (don't overwrite if already set)
+            if 'user_id' in extra_kwargs:
+                self._current_user_id = extra_kwargs.get('user_id')
             # Use adapter manager to prepare messages
             messages = self._prepare_messages(input_data)
             
@@ -604,19 +607,23 @@ class OpenAILLMService(BaseLLMService):
     
     async def _track_billing(self, usage):
         """Track billing information"""
+        import logging
+        logger = logging.getLogger(__name__)
+        logger.info(f"_track_billing called with user_id={self._current_user_id}")
+
         provider_config = self.get_provider_config()
-        
+
         # Prepare metadata for tracking
         metadata = {
-            "temperature": provider_config.get("temperature", 0.7), 
+            "temperature": provider_config.get("temperature", 0.7),
             "max_tokens": provider_config.get("max_tokens", 1024),
             "is_reasoning_model": self.is_reasoning_model
         }
-        
+
         # Add reasoning tokens if available for O-series models
         if self.is_reasoning_model and hasattr(usage, 'reasoning_tokens'):
             metadata["reasoning_tokens"] = usage.reasoning_tokens
-        
+
         # Get tokens using the same logic as _update_token_usage
         if hasattr(usage, 'prompt_tokens'):
             input_tokens = usage.prompt_tokens
@@ -627,14 +634,20 @@ class OpenAILLMService(BaseLLMService):
         else:
             input_tokens = 0
             output_tokens = 0
-            
-        await self._track_usage(
-            service_type=ServiceType.LLM,
-            operation="chat",
-            input_tokens=input_tokens,
-            output_tokens=output_tokens,
-            metadata=metadata
-        )
+
+        logger.info(f"Token usage: input={input_tokens}, output={output_tokens}")
+
+        # Publish billing event if user_id is available
+        if self._current_user_id:
+            logger.info(f"About to call _publish_billing_event for user={self._current_user_id}")
+            await self._publish_billing_event(
+                user_id=self._current_user_id,
+                service_type=ServiceType.LLM,
+                operation="chat",
+                input_tokens=input_tokens,
+                output_tokens=output_tokens,
+                metadata=metadata
+            )
     
     def get_token_usage(self) -> Dict[str, Any]:
         """Get total token usage statistics"""
