@@ -31,6 +31,21 @@ except ImportError:
     OllamaVisionService = None
     OLLAMA_VISION_AVAILABLE = False
 
+# Computer Vision specialized services
+try:
+    from .vgg16_vision_service import VGG16VisionService
+    VGG16_VISION_AVAILABLE = True
+except ImportError:
+    VGG16VisionService = None
+    VGG16_VISION_AVAILABLE = False
+
+try:
+    from .blip_vision_service import BLIPVisionService
+    BLIP_VISION_AVAILABLE = True
+except ImportError:
+    BLIPVisionService = None
+    BLIP_VISION_AVAILABLE = False
+
 __all__ = [
     "BaseVisionService",
     "OpenAIVisionService", 
@@ -43,4 +58,10 @@ if ISA_VISION_AVAILABLE:
     __all__.append("ISAVisionService")
 
 if OLLAMA_VISION_AVAILABLE:
-    __all__.append("OllamaVisionService") 
\ No newline at end of file
+    __all__.append("OllamaVisionService")
+
+if VGG16_VISION_AVAILABLE:
+    __all__.append("VGG16VisionService")
+
+if BLIP_VISION_AVAILABLE:
+    __all__.append("BLIPVisionService") 
\ No newline at end of file
