@@ -51,23 +51,26 @@ class OpenAIVisionService(BaseVisionService, VisionPromptMixin):
         reraise=True
     )
     async def analyze_image(
-        self, 
+        self,
         image: Union[str, BinaryIO],
         prompt: Optional[str] = None,
-        max_tokens: int = 1000
+        max_tokens: int = 1000,
+        **kwargs
     ) -> Dict[str, Any]:
         """
         Analyze image and provide description or answer questions
-        
+
         Args:
             image: Path to image file, URL, or image data
             prompt: Optional text prompt/question about the image
             max_tokens: Maximum tokens in response
-            
+
         Returns:
             Dict containing analysis results
         """
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
             # Use unified image processing from image_utils
             base64_image = prepare_image_base64(image)
             
@@ -109,13 +112,14 @@ class OpenAIVisionService(BaseVisionService, VisionPromptMixin):
             response = await self._client.chat.completions.create(**completion_params)  # type: ignore
             
             # Track usage for billing
-            if response.usage:
-                await self._track_usage(
+            if response.usage and self._current_user_id:
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
                     service_type=ServiceType.VISION,
                     operation="image_analysis",
                     input_tokens=response.usage.prompt_tokens,
                     output_tokens=response.usage.completion_tokens,
-                    metadata={"prompt": prompt[:100], "model": self.model_name}
+                    metadata={"prompt": prompt[:100] if prompt else "", "model": self.model_name}
                 )
             
             content = response.choices[0].message.content or ""
