@@ -65,15 +65,19 @@ class ReplicateVisionService(BaseVisionService, VisionPromptMixin):
     # 直接实现对应的标准方法即可
     
     async def analyze_image(
-        self, 
+        self,
         image: Union[str, BinaryIO],
         prompt: Optional[str] = None,
-        max_tokens: int = 1000
+        max_tokens: int = 1000,
+        **kwargs
     ) -> Dict[str, Any]:
         """
         Analyze image and provide description or answer questions
         """
         try:
+            # Extract user_id from kwargs for billing
+            self._current_user_id = kwargs.get('user_id')
+
             # Prepare image for API using unified processing
             image_input = self._prepare_image(image)
             
@@ -106,13 +110,15 @@ class ReplicateVisionService(BaseVisionService, VisionPromptMixin):
             response_text = str(output) if output else ""
             
             # Track usage for billing
-            await self._track_usage(
-                service_type=ServiceType.VISION,
-                operation="image_analysis",
-                input_tokens=len(prompt.split()) if prompt else 0,
-                output_tokens=len(response_text.split()),
-                metadata={"prompt": prompt[:100] if prompt else "", "model": self.model_name}
-            )
+            if self._current_user_id:
+                await self._publish_billing_event(
+                    user_id=self._current_user_id,
+                    service_type=ServiceType.VISION,
+                    operation="image_analysis",
+                    input_tokens=len(prompt.split()) if prompt else 0,
+                    output_tokens=len(response_text.split()),
+                    metadata={"prompt": prompt[:100] if prompt else "", "model": self.model_name}
+                )
             
             return {
                 "text": response_text,
