@@ -15,7 +15,7 @@ import logging
 import os
 from typing import Dict, Any, Optional
 
-from .routes import health, unified, deployments, logs, analytics, settings, inference_monitoring, webhooks, tenants  # config, training, annotation, and evaluations temporarily disabled
+from .routes import health, inference, deployments, logs, analytics, settings, inference_monitoring, webhooks, tenants  # Using inference.py (direct AIFactory access)
 from .middleware.request_logger import RequestLoggerMiddleware
 from .middleware.security import setup_security_middleware, check_redis_health
 from .middleware.tenant_context import TenantContextMiddleware
@@ -158,8 +158,8 @@ def create_app(config: Dict[str, Any] = None) -> FastAPI:
     # Include routers
     app.include_router(health.router, prefix="/health", tags=["health"])
     
-    # MAIN UNIFIED API - Single endpoint for all AI services
-    app.include_router(unified.router, prefix="/api/v1", tags=["unified-api"])
+    # MAIN INFERENCE API - Direct AIFactory access (no ISAModelClient middleman)
+    app.include_router(inference.router, prefix="/api/v1", tags=["inference-api"])
     
     # DEPLOYMENTS API - Model deployment management
     app.include_router(deployments.router, prefix="/api/v1/deployments", tags=["deployments"])
