@@ -14,12 +14,15 @@ import asyncpg
 import os
 from collections import defaultdict
 
+from ....core.config.config_manager import ConfigManager
+
 logger = logging.getLogger(__name__)
 
 router = APIRouter()
 
 # Database connection configuration
-DATABASE_URL = os.getenv("DATABASE_URL", "postgresql://postgres:postgres@127.0.0.1:54322/postgres?options=-c%20search_path%3Ddev")
+config_manager = ConfigManager()
+DATABASE_URL = os.getenv("DATABASE_URL", config_manager.get_global_config().database.default_database_url)
 
 class AnalyticsDateRange(BaseModel):
     start_date: Optional[str] = None
